==> hpm-cli-1.0.2.tgz: package/lib/main.js <==
"use strict";

require("@babel/polyfill");

var _commander = _interopRequireDefault(require("commander"));

var _package = require("../package");

var _config = require("./utils/config");

var _events = _interopRequireDefault(require("events"));

var _i18n = require("./i18n");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

_events["default"].EventEmitter.defaultMaxListeners = 100;

function actionEntrance() {
  switch (this._name) {
    // 这里的this指的是具体的commander
    case 'init':
      var _require = require("./commands/init"),
          init = _require.init;

      init.call.apply(init, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'build':
      var _require2 = require("./commands/build"),
          build = _require2.build;

      build.call.apply(build, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'pack':
      var _require3 = require("./commands/pack"),
          pack = _require3.pack;

      pack.call.apply(pack, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'dist':
      var _require4 = require("./commands/distribute"),
          distribute = _require4.distribute;

      distribute.call.apply(distribute, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'install':
      var _require5 = require("./commands/install"),
          install = _require5.install;

      install.call.apply(install, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'uninstall':
      var _require6 = require("./commands/uninstall"),
          uninstall = _require6.uninstall;

      uninstall.call.apply(uninstall, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'publish':
      var _require7 = require("./commands/publish"),
          publish = _require7.publish;

      publish.call.apply(publish, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'dependencies':
      var _require8 = require("./commands/dependencies"),
          dependencies = _require8.dependencies;

      dependencies.call.apply(dependencies, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'run':
      var _require9 = require("./commands/run"),
          run = _require9.run;

      run.call.apply(run, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'config':
      var _require10 = require("./commands/config"),
          config = _require10.config;

      config.call.apply(config, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'search':
      var _require11 = require("./commands/search"),
          search = _require11.search;

      search.call.apply(search, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'login':
      var _require12 = require("./commands/login"),
          login = _require12.login;

      login.call.apply(login, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'whoami':
      var _require13 = require("./commands/whoami"),
          whoami = _require13.whoami;

      whoami.call.apply(whoami, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'logout':
      var _require14 = require("./commands/logout"),
          logout = _require14.logout;

      logout.call.apply(logout, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'update':
      var _require15 = require("./commands/update"),
          update = _require15.update;

      update.call.apply(update, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'check-update':
      var _require16 = require("./commands/checkUpdate"),
          checkUpdate = _require16.checkUpdate;

      checkUpdate.call.apply(checkUpdate, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'list':
      var _require17 = require("./commands/list"),
          list = _require17.list;

      list.call.apply(list, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'gen-notice':
      var _require18 = require("./commands/generateNotice"),
          generateNotice = _require18.generateNotice;

      generateNotice.call.apply(generateNotice, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'gen-keys':
      var _require19 = require("./commands/generateKeys"),
          generateKeys = _require19.generateKeys;

      generateKeys.call.apply(generateKeys, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'extract':
      var _require20 = require("./commands/extract"),
          extract = _require20.extract;

      extract.call.apply(extract, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    default:
      break;
  }
}

(0, _config.initConfig)();

_commander["default"].version(_package.version);

_commander["default"].command('init').description((0, _i18n.getI18nMessage)('help.init')).option('-t, --template <template>', (0, _i18n.getI18nMessage)('help.initTemplate')).option('-d, --dirname <dirname>', (0, _i18n.getI18nMessage)('help.initDir')).option('-s, --scope <scopename>', (0, _i18n.getI18nMessage)('help.initScope')).arguments('[name]').action(actionEntrance);

_commander["default"].command('build').description((0, _i18n.getI18nMessage)('help.build')).action(actionEntrance);

_commander["default"].command('pack').description((0, _i18n.getI18nMessage)('help.pack')).action(actionEntrance);

_commander["default"].command('dist').description((0, _i18n.getI18nMessage)('help.dist')).action(actionEntrance);

_commander["default"].command('install').alias('i').alias('add').arguments('[name]').description((0, _i18n.getI18nMessage)('help.install')).action(actionEntrance).option('-g, --global', (0, _i18n.getI18nMessage)('help.installGlobal')).option('-d, --save-dev', (0, _i18n.getI18nMessage)('help.installDev'));

_commander["default"].command('uninstall').alias('rm').alias('remove').arguments('<name>').description((0, _i18n.getI18nMessage)('help.uninstall')).action(actionEntrance).option('-g, --global', (0, _i18n.getI18nMessage)('help.uninstallGlobal')).option('-d, --save-dev', (0, _i18n.getI18nMessage)('help.uninstallDev'));

_commander["default"].command('publish').description((0, _i18n.getI18nMessage)("help.publish")).option('-o, --old', (0, _i18n.getI18nMessage)("help.publishOld")).action(actionEntrance);

_commander["default"].command('dependencies').description((0, _i18n.getI18nMessage)('help.dependencies')).action(actionEntrance);

_commander["default"].command('run').description((0, _i18n.getI18nMessage)('help.run')).arguments('<cmd>').action(actionEntrance);

_commander["default"].command('config').description((0, _i18n.getI18nMessage)('help.config')).action(actionEntrance).option('set <key> <value>', (0, _i18n.getI18nMessage)('help.configSet')).option('-j, --json', (0, _i18n.getI18nMessage)('help.searchJson')).option('delete <key>', (0, _i18n.getI18nMessage)('help.configDelete'));

_commander["default"].command('search').description((0, _i18n.getI18nMessage)('help.search')).option('-t, --type <type>', (0, _i18n.getI18nMessage)('help.searchType')).option('-j, --json', (0, _i18n.getI18nMessage)('help.searchJson')).option('-p, --pageSize <pageSize>', (0, _i18n.getI18nMessage)('help.searchPagesize')).option('-c, --currentPage <currentPage>', (0, _i18n.getI18nMessage)('help.searchCurrentpage')).option('-v, --version <latest|all|semver>', (0, _i18n.getI18nMessage)('help.searchVersion')).arguments('[name]').action(actionEntrance);

_commander["default"].command('update').alias('up').alias('upgrade').arguments('[name]').description((0, _i18n.getI18nMessage)('help.update')).action(actionEntrance).option('-g, --global', (0, _i18n.getI18nMessage)('help.updateGlobal'));

_commander["default"].command('check-update').description((0, _i18n.getI18nMessage)('help.checkUpdate')).action(actionEntrance).option('-g, --global', (0, _i18n.getI18nMessage)('help.checkUpdateGlobal')).option('-j, --json', (0, _i18n.getI18nMessage)('help.checkUpdateJson'));

_commander["default"].command('list').alias('ls').description((0, _i18n.getI18nMessage)('help.list')).option('-j, --json', (0, _i18n.getI18nMessage)('help.searchJson')).option('-g, --global', (0, _i18n.getI18nMessage)('help.listGlobal')).action(actionEntrance);

_commander["default"].command('gen-notice').description((0, _i18n.getI18nMessage)('help.genNotice')).option('-d, --dirname <dirname>', (0, _i18n.getI18nMessage)('help.genNoticeDir')).action(actionEntrance);

_commander["default"].command('gen-keys').description((0, _i18n.getI18nMessage)('help.genKeys')).action(actionEntrance);

_commander["default"].command('extract').alias('x').arguments('<source> [target]').description((0, _i18n.getI18nMessage)('help.extract')).action(actionEntrance);

_commander["default"].parse(process.argv);

==> hpm-cli-1.0.3.tgz: package/lib/main.js <==
"use strict";

require("@babel/polyfill");

var _commander = _interopRequireDefault(require("commander"));

var _events = _interopRequireDefault(require("events"));

var _package = require("../package.json");

var _config = require("./utils/config");

var _i18n = require("./i18n");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/*eslint-disable*/
_events["default"].EventEmitter.defaultMaxListeners = 100;

function actionEntrance() {
  switch (this._name) {
    // 这里的this指的是具体的commander
    case 'init':
      var _require = require('./commands/init'),
          init = _require.init;

      init.call.apply(init, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'build':
      var _require2 = require('./commands/build'),
          build = _require2.build;

      build.call.apply(build, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'pack':
      var _require3 = require('./commands/pack'),
          pack = _require3.pack;

      pack.call.apply(pack, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'dist':
      var _require4 = require('./commands/distribute'),
          distribute = _require4.distribute;

      distribute.call.apply(distribute, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'install':
      var _require5 = require('./commands/install'),
          install = _require5.install;

      install.call.apply(install, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'uninstall':
      var _require6 = require('./commands/uninstall'),
          uninstall = _require6.uninstall;

      uninstall.call.apply(uninstall, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'publish':
      var _require7 = require('./commands/publish'),
          publish = _require7.publish;

      publish.call.apply(publish, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'dependencies':
      var _require8 = require('./commands/dependencies'),
          dependencies = _require8.dependencies;

      dependencies.call.apply(dependencies, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'run':
      var _require9 = require('./commands/run'),
          run = _require9.run;

      run.call.apply(run, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'config':
      var _require10 = require('./commands/config'),
          config = _require10.config;

      config.call.apply(config, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'search':
      var _require11 = require('./commands/search'),
          search = _require11.search;

      search.call.apply(search, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'login':
      var _require12 = require('./commands/login'),
          login = _require12.login;

      login.call.apply(login, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'whoami':
      var _require13 = require('./commands/whoami'),
          whoami = _require13.whoami;

      whoami.call.apply(whoami, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'logout':
      var _require14 = require('./commands/logout'),
          logout = _require14.logout;

      logout.call.apply(logout, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'update':
      var _require15 = require('./commands/update'),
          update = _require15.update;

      update.call.apply(update, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'check-update':
      var _require16 = require('./commands/checkUpdate'),
          checkUpdate = _require16.checkUpdate;

      checkUpdate.call.apply(checkUpdate, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'list':
      var _require17 = require('./commands/list'),
          list = _require17.list;

      list.call.apply(list, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'gen-notice':
      var _require18 = require('./commands/generateNotice'),
          generateNotice = _require18.generateNotice;

      generateNotice.call.apply(generateNotice, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'gen-keys':
      var _require19 = require('./commands/generateKeys'),
          generateKeys = _require19.generateKeys;

      generateKeys.call.apply(generateKeys, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    case 'extract':
      var _require20 = require('./commands/extract'),
          extract = _require20.extract;

      extract.call.apply(extract, [this].concat(Array.prototype.slice.call(arguments)));
      break;

    default:
      break;
  }
}

(0, _config.initConfig)();

_commander["default"].version(_package.version);

_commander["default"].command('init').description((0, _i18n.getI18nMessage)('help.init')).option('-t, --template <template>', (0, _i18n.getI18nMessage)('help.initTemplate')).option('-d, --dirname <dirname>', (0, _i18n.getI18nMessage)('help.initDir')).option('-s, --scope <scopename>', (0, _i18n.getI18nMessage)('help.initScope')).arguments('[name]').action(actionEntrance);

_commander["default"].command('build').description((0, _i18n.getI18nMessage)('help.build')).action(actionEntrance);

_commander["default"].command('pack').description((0, _i18n.getI18nMessage)('help.pack')).action(actionEntrance);

_commander["default"].command('dist').description((0, _i18n.getI18nMessage)('help.dist')).action(actionEntrance);

_commander["default"].command('install').alias('i').alias('add').arguments('[name]').description((0, _i18n.getI18nMessage)('help.install')).action(actionEntrance).option('-g, --global', (0, _i18n.getI18nMessage)('help.installGlobal')).option('-d, --save-dev', (0, _i18n.getI18nMessage)('help.installDev'));

_commander["default"].command('uninstall').alias('rm').alias('remove').arguments('<name>').description((0, _i18n.getI18nMessage)('help.uninstall')).action(actionEntrance).option('-g, --global', (0, _i18n.getI18nMessage)('help.uninstallGlobal')).option('-d, --save-dev', (0, _i18n.getI18nMessage)('help.uninstallDev'));

_commander["default"].command('publish').description((0, _i18n.getI18nMessage)('help.publish')).option('-o, --old', (0, _i18n.getI18nMessage)('help.publishOld')).action(actionEntrance);

_commander["default"].command('dependencies').description((0, _i18n.getI18nMessage)('help.dependencies')).action(actionEntrance);

_commander["default"].command('run').description((0, _i18n.getI18nMessage)('help.run')).arguments('<cmd>').action(actionEntrance);

_commander["default"].command('config').description((0, _i18n.getI18nMessage)('help.config')).action(actionEntrance).option('set <key> <value>', (0, _i18n.getI18nMessage)('help.configSet')).option('-j, --json', (0, _i18n.getI18nMessage)('help.searchJson')).option('delete <key>', (0, _i18n.getI18nMessage)('help.configDelete'));

_commander["default"].command('search').description((0, _i18n.getI18nMessage)('help.search')).option('-t, --type <type>', (0, _i18n.getI18nMessage)('help.searchType')).option('-j, --json', (0, _i18n.getI18nMessage)('help.searchJson')).option('-p, --pageSize <pageSize>', (0, _i18n.getI18nMessage)('help.searchPagesize')).option('-c, --currentPage <currentPage>', (0, _i18n.getI18nMessage)('help.searchCurrentpage')).option('-v, --version <latest|all|semver>', (0, _i18n.getI18nMessage)('help.searchVersion')).arguments('[name]').action(actionEntrance);

_commander["default"].command('update').alias('up').alias('upgrade').arguments('[name]').description((0, _i18n.getI18nMessage)('help.update')).action(actionEntrance).option('-g, --global', (0, _i18n.getI18nMessage)('help.updateGlobal'));

_commander["default"].command('check-update').description((0, _i18n.getI18nMessage)('help.checkUpdate')).action(actionEntrance).option('-g, --global', (0, _i18n.getI18nMessage)('help.checkUpdateGlobal')).option('-j, --json', (0, _i18n.getI18nMessage)('help.checkUpdateJson'));

_commander["default"].command('list').alias('ls').description((0, _i18n.getI18nMessage)('help.list')).option('-j, --json', (0, _i18n.getI18nMessage)('help.searchJson')).option('-g, --global', (0, _i18n.getI18nMessage)('help.listGlobal')).action(actionEntrance);

_commander["default"].command('gen-notice').description((0, _i18n.getI18nMessage)('help.genNotice')).option('-d, --dirname <dirname>', (0, _i18n.getI18nMessage)('help.genNoticeDir')).action(actionEntrance);

_commander["default"].command('gen-keys').description((0, _i18n.getI18nMessage)('help.genKeys')).action(actionEntrance);

_commander["default"].command('extract').alias('x').arguments('<source> [target]').description((0, _i18n.getI18nMessage)('help.extract')).action(actionEntrance);

_commander["default"].parse(process.argv);
